# -*- coding: utf-8 -*-
from . import response
from . import client

class SimRequest(object):
    OPERATOR_CHINAMOBILE = 1
    OPERATOR_CHINAUNICOM = 2
    OPERATOR_CHINATELCOM = 3

    def __init__(self):
        return

    def get_package_list(self, page = 1, size = 20):
        params = client.RequestParam()
        params.method = params.GET
        params.payload = {
            "page": page,
            "size": size,
        }
        params.path = f"cardapi/package/list"
        return params

    def get_card_list(self, cardflag = 1, operator = None, order = None, page = 1, size = 20, sortfield = None, status = None):
        params = client.RequestParam()
        params.path = f"cardapi/card/list/"
        params.method = params.POST
        params.payload = {
            "cardFlag": cardflag,
            "operator": operator or self.OPERATOR_CHINAMOBILE,
            "order": order,
            "pageindex": page,
            "pagesize": size,
            "sortfield": sortfield,
        }
        return params

    def get_card(self, iccid = None):
        if iccid == None:
            return response.PARAM_ERROR

        params = client.RequestParam()
        params.method = params.GET
        params.path = f"cardapi/card/{iccid}/"

        return params

    def get_share_pool_list(self):
        params = client.RequestParam()
        params.path = f"cardapi/cardsharepool/list/"
        params.method = params.POST
        params.payload = {}
        return params

    def get_card_month_usage(self, iccid, month):
        params = client.RequestParam()
        params.path = f"cardapi/card_flow/month/"
        params.method = params.POST
        params.payload = {
            "iccid": iccid,
            "month": month,
        }
        return params


"""
sealan-cloud-sdk-v1
-------------

This is the description for that library
"""
import os
from setuptools import setup, find_packages

import sealan_sdk

ROOT = os.path.dirname(__file__)

setup(
    name='sealan-sdk',
    version=sealan_sdk.__version__,
    description='Sealan Cloud SDK for Python',
    long_description=open('README.rst').read(),
    author='Sealan Cloud',
    url='https://github.com/sealan-cloud/sealan-sdk-python',
    maintainer_email="zhong@sealan.tech",
    scripts=[],
    install_requires = ['requests>=2.26.0'],
    packages=find_packages(exclude=["tests*", "example*"]),
    license="Apache License 2.0",
    platforms='any',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)


# -*- coding: utf-8 -*-
from . import response
from . import client

class DeviceRequest(object):

    def __init__(self):
        return

    def get_device_list(self, sorter = None, page = 1, size = 20):
        params = client.RequestParam()
        params.path = f"server/device/list"
        params.method = params.POST
        params.payload = {
            "pageindex": page,
            "pagesize": size,
            "sorter": sorter,
        }
        return params



# -*- coding: utf-8 -*-
import json

AUTH_ERROR = {
    "error_code": 10011,
    "msg": "auth fail"
}

PARAM_ERROR = {
    "error_code": 10012,
    "msg": "param error"
}

def http_status_error(r):
    return {
        "error_code": r.status_code
    }


# -*- coding: utf-8 -*-
import sys
import requests
import os

from . import response

class Client(object):
    scheme = "https"

    def __init__(self, protocol = None, endpoint = None, method = None, timeout = 60, proxy = None, domain = None):
        """HTTP profile.
        :param protocol: http or https, default is https.
        :type protocol: str
        :param endpoint: The domain to access, like: cvm.tencentcloudapi.com
        :type endpoint: str
        """
        self.protocol = protocol or "https"
        self.endpoint = endpoint or "cloud.sealan.tech"
        self.method = method or "post"
        self.timeout = timeout
        self.proxy = proxy
        self.domain = domain
        self.token = None

    def request(self, params = None):

        if params == None:
            return None

        if self.token == None:
            self.get_token()

        if self.token == None:
            return {"error": "get token error"}

        if params.method == params.GET:
            return self.get(params)

        elif params.method == params.POST:
            return self.post(params)

    def get(self, params):
        headers = {
            "Authorization": f"Bearer {self.token}",
            "user-agent": "sealan-cloud-sdk-python-v1"
        }

        url = f"{self.protocol}://{self.endpoint}/{params.path}?token={self.token}"
        r = requests.get(url, params = params.payload, headers = headers)
        if r.status_code == requests.codes.ok:
            return r.json()

    def post(self, params):
        headers = {
            "Authorization": f"Bearer {self.token}",
            "user-agent": "sealan-cloud-sdk-python-v1",
            'Content-Type': 'application/json;charset=UTF-8'
        }

        url = f"{self.protocol}://{self.endpoint}/{params.path}?token={self.token}"
        r = requests.post(url, json = params.payload)
        if r.status_code == requests.codes.ok:
            return r.json()
        else:
            return response.http_status_error(r)

    def get_token(self):
        payload = {
            'grant_type': "client_credential",
            'appid': self.appid,
            'secret': self.secret
        }
        r = requests.get(f"{self.protocol}://{self.endpoint}/user/token", params = payload)
        if r.status_code != requests.codes.ok:
            return response.AUTH_ERROR

        self.token = r.json()["token"]

class RequestParam(object):
    def __init__(self, method = None, path = None, payload = None):
        self.method = method or "get"
        self.path = path
        self.payload = payload
        self.GET = "get"
        self.POST = "post"